<?php
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

// Overwrite parent theme background defaults and registers support for WordPress features.
add_action( 'after_setup_theme', 'lalita_background_setup' );
function lalita_background_setup() {
	add_theme_support( "custom-background",
		array(
			'default-color' 		 => 'FDFDF5',
			'default-image'          => '',
			'default-repeat'         => 'repeat',
			'default-position-x'     => 'left',
			'default-position-y'     => 'top',
			'default-size'           => 'auto',
			'default-attachment'     => '',
			'wp-head-callback'       => '_custom_background_cb',
			'admin-head-callback'    => '',
			'admin-preview-callback' => ''
		)
	);
}

// Overwrite theme URL
function lalita_theme_uri_link() {
	return 'https://wpkoi.com/pandita-wpkoi-wordpress-theme/';
}

// Overwrite parent theme's blog header function
add_action( 'lalita_after_header', 'lalita_blog_header_image', 11 );
function lalita_blog_header_image() {

	if ( ( is_front_page() && is_home() ) || ( is_home() ) ) { 
		$blog_header_image 			=  lalita_get_setting( 'blog_header_image' ); 
		$blog_header_title 			=  lalita_get_setting( 'blog_header_title' ); 
		$blog_header_text 			=  lalita_get_setting( 'blog_header_text' ); 
		$blog_header_button_text 	=  lalita_get_setting( 'blog_header_button_text' ); 
		$blog_header_button_url 	=  lalita_get_setting( 'blog_header_button_url' ); 
		if ( $blog_header_image != '' ) { ?>
		<div class="page-header-image grid-parent page-header-blog" style="background-image: url('<?php echo esc_url($blog_header_image); ?>') !important;">
        	<div class="page-header-noiseoverlay"></div>
        	<div class="page-header-blog-inner">
                <div class="page-header-blog-content-h grid-container">
                    <div class="page-header-blog-content">
                    <?php if ( $blog_header_title != '' ) { ?>
                        <div class="page-header-blog-text">
                            <?php if ( $blog_header_title != '' ) { ?>
                            <h2><?php echo wp_kses_post( $blog_header_title ); ?></h2>
                            <div class="clearfix"></div>
                            <?php } ?>
                        </div>
                    <?php } ?>
                    </div>
                </div>
                <div class="page-header-blog-content page-header-blog-content-b">
                	<?php if ( $blog_header_text != '' ) { ?>
                	<div class="page-header-blog-text">
						<?php if ( $blog_header_title != '' ) { ?>
                        <p><?php echo wp_kses_post( $blog_header_text ); ?></p>
                        <div class="clearfix"></div>
                        <?php } ?>
                    </div>
                    <?php } ?>
                    <div class="page-header-blog-button">
                        <?php if ( $blog_header_button_text != '' ) { ?>
                        <a class="read-more button" href="<?php echo esc_url( $blog_header_button_url ); ?>"><?php echo esc_html( $blog_header_button_text ); ?></a>
                        <?php } ?>
                    </div>
                </div>
            </div>
		</div>
		<?php
		}
	}
}

// Extra cutomizer functions
if ( ! function_exists( 'pandita_customize_register' ) ) {
	add_action( 'customize_register', 'pandita_customize_register' );
	function pandita_customize_register( $wp_customize ) {
				
		// Add Pandita customizer section
		$wp_customize->add_section(
			'pandita_layout_effects',
			array(
				'title' => __( 'Pandita Effects', 'pandita' ),
				'priority' => 24,
			)
		);
		
		
		// Header border
		$wp_customize->add_setting(
			'pandita_settings[header_border]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'pandita_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'pandita_settings[header_border]',
			array(
				'type' => 'select',
				'label' => __( 'Header border', 'pandita' ),
				'choices' => array(
					'enable' => __( 'Enable', 'pandita' ),
					'disable' => __( 'Disable', 'pandita' )
				),
				'settings' => 'pandita_settings[header_border]',
				'section' => 'pandita_layout_effects',
				'priority' => 1
			)
		);
		
		// Top bar icons
		$wp_customize->add_setting(
			'pandita_settings[top_bar_icons]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'pandita_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'pandita_settings[top_bar_icons]',
			array(
				'type' => 'select',
				'label' => __( 'Top bar icons', 'pandita' ),
				'choices' => array(
					'enable' => __( 'Enable', 'pandita' ),
					'disable' => __( 'Disable', 'pandita' )
				),
				'settings' => 'pandita_settings[top_bar_icons]',
				'section' => 'pandita_layout_effects',
				'priority' => 2
			)
		);
		
		// Widget boxes
		$wp_customize->add_setting(
			'pandita_settings[widget_boxes]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'pandita_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'pandita_settings[widget_boxes]',
			array(
				'type' => 'select',
				'label' => __( 'Widget boxes', 'pandita' ),
				'choices' => array(
					'enable' => __( 'Enable', 'pandita' ),
					'disable' => __( 'Disable', 'pandita' )
				),
				'settings' => 'pandita_settings[widget_boxes]',
				'section' => 'pandita_layout_effects',
				'priority' => 3
			)
		);
		
		// Big bottom site title
		$wp_customize->add_setting(
			'pandita_settings[bb_site_title]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'pandita_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'pandita_settings[bb_site_title]',
			array(
				'type' => 'select',
				'label' => __( 'Big bottom site title', 'pandita' ),
				'choices' => array(
					'enable' => __( 'Enable', 'pandita' ),
					'disable' => __( 'Disable', 'pandita' )
				),
				'settings' => 'pandita_settings[bb_site_title]',
				'section' => 'pandita_layout_effects',
				'priority' => 4
			)
		);
		
		// Cursor image
		$wp_customize->add_setting(
			'pandita_settings[cursor_image]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'pandita_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'pandita_settings[cursor_image]',
			array(
				'type' => 'select',
				'label' => __( 'Cursor image', 'pandita' ),
				'choices' => array(
					'enable' => __( 'Enable', 'pandita' ),
					'disable' => __( 'Disable', 'pandita' )
				),
				'settings' => 'pandita_settings[cursor_image]',
				'section' => 'pandita_layout_effects',
				'priority' => 9
			)
		);
		
		$wp_customize->add_setting(
			'pandita_settings[def_cursor_image]',
			array(
				'default' => '',
				'type' => 'option',
				'sanitize_callback' => 'esc_url_raw'
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'pandita_settings[def_cursor_image]',
				array(
					'label' => __( 'Default cursor image', 'pandita' ),
					'section' => 'pandita_layout_effects',
					'priority' => 10,
					'settings' => 'pandita_settings[def_cursor_image]',
					'description' => __( 'Recommended size: 32*32px. Big image won`t work.', 'pandita' )
				)
			)
		);
		
		$wp_customize->add_setting(
			'pandita_settings[pointer_cursor_image]',
			array(
				'default' => '',
				'type' => 'option',
				'sanitize_callback' => 'esc_url_raw'
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'pandita_settings[pointer_cursor_image]',
				array(
					'label' => __( 'Pointer cursor image', 'pandita' ),
					'section' => 'pandita_layout_effects',
					'priority' => 11,
					'settings' => 'pandita_settings[pointer_cursor_image]',
					'description' => __( 'Recommended size: 32*32px. Big image won`t work.', 'pandita' )
				)
			)
		);
		
	}
}

//Sanitize choices.
if ( ! function_exists( 'pandita_sanitize_choices' ) ) {
	function pandita_sanitize_choices( $input, $setting ) {
		// Ensure input is a slug
		$input = sanitize_key( $input );

		// Get list of choices from the control
		// associated with the setting
		$choices = $setting->manager->get_control( $setting->id )->choices;

		// If the input is a valid key, return it;
		// otherwise, return the default
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
	}
}

// Pandita cursor images
if ( ! function_exists( 'pandita_cursor_images_css' ) ) {
	function pandita_cursor_images_css() {
		// Get Customizer settings
		$pandita_settings = get_option( 'pandita_settings' );
		
		$def_cursor_image  	  = '';
		$pointer_cursor_image = '';
		
		if ( isset( $pandita_settings['def_cursor_image'] ) ) {
			$def_cursor_image = $pandita_settings['def_cursor_image'];
		}
		if ( isset( $pandita_settings['pointer_cursor_image'] ) ) {
			$pointer_cursor_image = $pandita_settings['pointer_cursor_image'];
		}
		
		$pandita_cursorimages = '';
		
		if ( $def_cursor_image != '' ) {
			$pandita_cursorimages .= 'body.pandita-cursor-image{cursor: url(' . esc_url( $def_cursor_image ) . '), auto; }';
		}
		if ( $pointer_cursor_image != '' ) {
			$pandita_cursorimages .= '.pandita-cursor-image a, .pandita-cursor-image input[type="submit"]:hover {cursor: url(' . esc_url( $pointer_cursor_image ) . '), auto; }';
		}
		
		return $pandita_cursorimages;
	}
}


// The dynamic styles of the parent theme added inline to the parent stylesheet.
// For the customizer functions it is better to enqueue after the child theme stylesheet.
if ( ! function_exists( 'pandita_remove_parent_dynamic_css' ) ) {
	add_action( 'init', 'pandita_remove_parent_dynamic_css' );
	function pandita_remove_parent_dynamic_css() {
		remove_action( 'wp_enqueue_scripts', 'lalita_enqueue_dynamic_css', 50 );
	}
}

// Enqueue this CSS after the child stylesheet, not after the parent stylesheet.
if ( ! function_exists( 'pandita_enqueue_parent_dynamic_css' ) ) {
	add_action( 'wp_enqueue_scripts', 'pandita_enqueue_parent_dynamic_css', 50 );
	function pandita_enqueue_parent_dynamic_css() {
		$css = lalita_base_css() . lalita_font_css() . lalita_advanced_css() . lalita_spacing_css() . lalita_no_cache_dynamic_css() .pandita_cursor_images_css();

		// escaped secure before in parent theme
		wp_add_inline_style( 'lalita-child', $css );
	}
}

//Adds custom classes to the array of body classes.
if ( ! function_exists( 'pandita_body_classes' ) ) {
	add_filter( 'body_class', 'pandita_body_classes' );
	function pandita_body_classes( $classes ) {
		// Get Customizer settings
		$pandita_settings = get_option( 'pandita_settings' );
		
		$header_border 	    = 'enable';
		$top_bar_icons		= 'enable';
		$widget_boxes  	    = 'enable';
		$cursor_image		= 'enable';
		
		if ( isset( $pandita_settings['header_border'] ) ) {
			$header_border = $pandita_settings['header_border'];
		}
		
		if ( isset( $pandita_settings['top_bar_icons'] ) ) {
			$top_bar_icons = $pandita_settings['top_bar_icons'];
		}
		
		if ( isset( $pandita_settings['widget_boxes'] ) ) {
			$widget_boxes = $pandita_settings['widget_boxes'];
		}
		
		if ( isset( $pandita_settings['cursor_image'] ) ) {
			$cursor_image = $pandita_settings['cursor_image'];
		}
		
		// Header border
		if ( $header_border != 'disable' ) {
			$classes[] = 'pandita-header-border';
		}
		
		// Top bar icons
		if ( $top_bar_icons != 'disable' ) {
			$classes[] = 'pandita-top-bar-icons';
		}
		
		// Widget boxes
		if ( $widget_boxes != 'disable' ) {
			$classes[] = 'pandita-widget-boxes';
		}
		
		// Cursor Image
		if ( $cursor_image != 'disable' ) {
			$classes[] = 'pandita-cursor-image';
		}
		
		return $classes;
	}
}

if ( ! function_exists( 'pandita_scripts' ) ) {
	add_action( 'wp_enqueue_scripts', 'pandita_scripts' );
	/**
	 * Enqueue script
	 */
	function pandita_scripts() {
		
		$pandita_settings = get_option( 'pandita_settings' );
		
		$bb_site_title		 = 'enable';
		if ( isset( $pandita_settings['bb_site_title'] ) ) {
			$bb_site_title = $pandita_settings['bb_site_title'];
		}
		
		if ( $bb_site_title != 'disable' ) {
			wp_enqueue_script( 'pandita-textfill', esc_url( get_stylesheet_directory_uri() ) . "/js/textFit.min.js", array( 'jquery'), LALITA_VERSION, true );
		}

	}
}

if ( ! function_exists( 'pandita_bottom_title' ) ) {
	add_action( 'lalita_footer', 'pandita_bottom_title' );
	/**
	 * HTML for bottom site title
	 */
	function pandita_bottom_title() {
		$pandita_settings = get_option( 'pandita_settings' );
		
		$bb_site_title 	   = 'enable';
		if ( isset( $pandita_settings['bb_site_title'] ) ) {
			$bb_site_title = $pandita_settings['bb_site_title'];
		}
		
		if ( $bb_site_title != 'disable' ) {
	?>
    <div id="pandita-textfill" class="footer-widgets footer-big-title">
    	<div class="textfit"><?php echo esc_html( get_bloginfo( 'name' ) ); ?></div>
    </div>
    <?php
		}
	}
}